@@ -2,6 +2,7 @@ import datetime
 from unittest import TestCase
 
 from pystac import Provider, MediaType
+from pystac.extensions.grid import GridExtension
 from pystac.extensions.projection import ProjectionExtension
 from pystac.extensions.raster import RasterExtension
 from pystac.provider import ProviderRole
@@ -60,6 +61,9 @@ class StacTest(TestCase):
             -0.0002777777777777778, 54.00013888888889
         ])
 
+        grid = GridExtension.ext(item)
+        self.assertEqual(grid.code, "CDEM-N53W115")
+
         handbook = item.get_single_link("handbook")
         self.assertIsNotNone(handbook)
         self.assertEqual(handbook.title, "Copernicus DEM User handbook")
@@ -77,6 +81,7 @@ class StacTest(TestCase):
         self.assertEqual(data.media_type, MediaType.COG)
         self.assertEqual(data.roles, ["data"])
 
+        self.assertTrue(GridExtension.has_extension(item))
         self.assertTrue(ProjectionExtension.has_extension(item))
         self.assertTrue(RasterExtension.has_extension(item))
 
@@ -121,6 +126,11 @@ class StacTest(TestCase):
             0.00125, 0.0, -115.000625, 0.0, -0.0008333333333333334,
             54.000416666666666
         ])
+        self.assertEqual(round(projection.centroid["lat"], 5), 53.5)
+        self.assertEqual(round(projection.centroid["lon"], 5), -114.5)
+
+        grid = GridExtension.ext(item)
+        self.assertEqual(grid.code, "CDEM-N53W115")
 
         handbook = item.get_single_link("handbook")
         self.assertIsNotNone(handbook)
@@ -141,6 +151,7 @@ class StacTest(TestCase):
 
         self.assertTrue(ProjectionExtension.has_extension(item))
         self.assertTrue(RasterExtension.has_extension(item))
+        self.assertTrue(GridExtension.has_extension(item))
 
         item.validate()  # raises STACValidationError if not
 
